@@ -19,6 +19,7 @@ import aiohttp
 
 from .code_mappings import RoborockDockTypeCode
 from .containers import (
+    ChildLockStatus,
     CleanRecord,
     CleanSummary,
     Consumable,
@@ -34,6 +35,7 @@ from .containers import (
     SmartWashParams,
     Status,
     UserData,
+    ValleyElectricityTimer,
     WashTowelMode,
 )
 from .exceptions import (
@@ -45,6 +47,7 @@ from .exceptions import (
     RoborockNoUserAgreement,
     RoborockTimeout,
     RoborockUrlException,
+    UnknownMethodError,
     VacuumError,
 )
 from .protocol import Utils
@@ -58,6 +61,7 @@ KEEPALIVE = 60
 QUEUE_TIMEOUT = 4
 COMMANDS_SECURED = [
     RoborockCommand.GET_MAP_V1,
+    RoborockCommand.GET_MULTI_MAP,
 ]
 
 
@@ -148,7 +152,7 @@ class RoborockClient:
                                     queue.resolve((result, None))
                 elif data.payload and protocol == 301:
                     payload = data.payload[0:24]
-                    [endpoint, _, request_id, _] = struct.unpack("<15sBH6s", payload)
+                    [endpoint, _, request_id, _] = struct.unpack("<8s8sH6s", payload)
                     if endpoint.decode().startswith(self._endpoint):
                         decrypted = Utils.decrypt_cbc(data.payload[24:], self._nonce)
                         decompressed = Utils.decompress(decrypted)
@@ -187,6 +191,8 @@ class RoborockClient:
             queue = RoborockFuture(protocol_id)
             self._waiting_queue[request_id] = queue
             (response, err) = await queue.async_get(QUEUE_TIMEOUT)
+            if response == "unknown_method":
+                raise UnknownMethodError("Unknown method")
             return response, err
         except (asyncio.TimeoutError, asyncio.CancelledError):
             raise RoborockTimeout(f"id={request_id} Timeout after {QUEUE_TIMEOUT} seconds") from None
@@ -200,7 +206,7 @@ class RoborockClient:
         secured=False,
     ):
         timestamp = math.floor(time.time())
-        request_id = randint(10000, 99999)
+        request_id = randint(10000, 32767)
         inner = {
             "id": request_id,
             "method": method,
@@ -242,6 +248,13 @@ class RoborockClient:
             return DnDTimer.from_dict(dnd_timer)
         return None
 
+    @fallback_cache
+    async def get_valley_electricity_timer(self) -> ValleyElectricityTimer | None:
+        valley_electricity_timer = await self.send_command(RoborockCommand.GET_VALLEY_ELECTRICITY_TIMER)
+        if isinstance(valley_electricity_timer, dict):
+            return ValleyElectricityTimer.from_dict(valley_electricity_timer)
+        return None
+
     @fallback_cache
     async def get_clean_summary(self) -> CleanSummary | None:
         clean_summary = await self.send_command(RoborockCommand.GET_CLEAN_SUMMARY)
@@ -369,6 +382,19 @@ class RoborockClient:
             ]
         return None
 
+    @fallback_cache
+    async def get_child_lock_status(self) -> ChildLockStatus | None:
+        """Gets current child lock status."""
+        child_lock_status = await self.send_command(RoborockCommand.GET_CHILD_LOCK_STATUS)
+        if isinstance(child_lock_status, dict):
+            return ChildLockStatus.from_dict(child_lock_status)
+        return None
+
+    @fallback_cache
+    async def get_sound_volume(self) -> int | None:
+        """Gets current volume level."""
+        return await self.send_command(RoborockCommand.GET_SOUND_VOLUME)
+
 
 class RoborockApiClient:
     def __init__(self, username: str, base_url=None) -> None:
